/* //////////////////////////////////////////////////////////////////////////////////////
Suite logicielle Pikasuite
Auteur: Julien PIASECKI
Mail : pikachu_42@hotmail.com ou julien.piasecki@hotmail.fr
Ensemble de fonctions de gestion de la calibration

///////////////////////////////////////////////////////////////////////////////////////*/
#include <htc.h>
#include <stdio.h>
#include "variables_globales.h"
#include "fonctions_globales.h"
#include "glcd.h"
#include "delay.h"
#include "io_config.h"
#include "adc_lib.h"


void calibration (void)
{
	int adc_rd = 0;						// valeur de l'ADC pour l'oscilloscope	
	int x_min, x_max, y_min, y_max;		// Coordonnes de calibration
	int calib_done = 0;					// flag qui indique calibration OK

	// Message de dpart
	GLCD_PUTSTRING("Calibration", 30, 2, 1); 
	GLCD_RECT(10, 30, 9, 120);	

	DelayMs(2000); 
	DelayMs(2000); 
	GLCD_CLR(); 

	// On affiche le premier point en bas  gauche
	GLCD_Draw_Point(0,63,1);

	// Message  l'cran
	GLCD_PUTSTRING("Appuyez en bas", 30, 2, 1); 
	GLCD_PUTSTRING("a gauche", 40, 3, 1);
	
	///////////////////////// Boucle de test de la valeur minimale///////////////////////
	do
	{
		// On teste si l'utilisateur n'a pas appuy sur la croix en haut  droite pour sortir
	    if (detect_touch()==1)														// on n'analyse l'appui que si dtect
        {
			// On lit les valeurs x et y
			PORTCbits.RC0 = 1;                //' DRIVEA = 1 (LEFT drive on, RIGHT drive on, TOP drive off)
			PORTCbits.RC1 = 0;                //' DRIVEB = 0 (BOTTOM drive off)
			DelayUs(500);	
			x_min = ADC_Read(0);		      // on stocke la valeur x_min

			PORTCbits.RC0 = 0;                //' DRIVEA = 1 (LEFT drive on, RIGHT drive on, TOP drive off)
			PORTCbits.RC1 = 1;                //' DRIVEB = 0 (BOTTOM drive off)
			DelayUs(500);	
			y_min = ADC_Read(1);		      //' on stocke la valeur y_min	
		
			calib_done = 1;					  // calibration valeurs mini faite		
		}

     }while (calib_done==0);

	GLCD_CLR(); 
	calib_done = 0;							  // on rinitialise le flag	
	
	// On affiche le premier point en bas  gauche
	GLCD_Draw_Point(127,0,1);

	// Message  l'cran
	GLCD_PUTSTRING("Appuyez en haut", 30, 2, 1); 
	GLCD_PUTSTRING("a droite", 40, 3, 1); 

	DelayMs(2000); 

	///////////////////////// Boucle de test de la valeur maximale///////////////////////
	do
	{
		// On teste si l'utilisateur n'a pas appuy sur la croix en haut  droite pour sortir
	    if (detect_touch()==1)														// on n'analyse l'appui que si dtect
        {
			// On lit les valeurs x et y
			PORTCbits.RC0 = 1;                //' DRIVEA = 1 (LEFT drive on, RIGHT drive on, TOP drive off)
			PORTCbits.RC1 = 0;                //' DRIVEB = 0 (BOTTOM drive off)
			DelayUs(500);	
			x_max = ADC_Read(0);		      // on stocke la valeur x_min

			PORTCbits.RC0 = 0;                //' DRIVEA = 1 (LEFT drive on, RIGHT drive on, TOP drive off)
			PORTCbits.RC1 = 1;                //' DRIVEB = 0 (BOTTOM drive off)
			DelayUs(500);	
			y_max = ADC_Read(1);		      //' on stocke la valeur y_min	
		
			calib_done = 1;					  // calibration valeurs mini faite		
		}

     }while (calib_done==0);

	// On affiche les rsultats mesurs
	GLCD_CLR(); 
	GLCD_RECT(0, 63, 0, 127);                                     	 // Cadre extrieur
	GLCD_PUTSTRING("X", 122, 0, 0);								 	 // croix en haut  gauche

	GLCD_PUTSTRING("Xmin = ", 10, 1, 1);
	GLCD_PUTSTRING("Xmax = ", 10, 2, 1);
	GLCD_PUTSTRING("Ymin = ", 10, 3, 1);
	GLCD_PUTSTRING("Ymax = ", 10, 4, 1);

	convert_adc_to_GLCD(x_min);
	GLCD_PUTCHAR(iCentaines, 52, 1, 1);
	GLCD_PUTCHAR(iDizaines, 58, 1, 1);
	GLCD_PUTCHAR(iUnites, 64, 1, 1);
	
	convert_adc_to_GLCD(x_max);
	GLCD_PUTCHAR(iCentaines, 52, 2, 1);
	GLCD_PUTCHAR(iDizaines, 58, 2, 1);
	GLCD_PUTCHAR(iUnites, 64, 2, 1);

	convert_adc_to_GLCD(y_min);
	GLCD_PUTCHAR(iCentaines, 52, 3, 1);
	GLCD_PUTCHAR(iDizaines, 58, 3, 1);
	GLCD_PUTCHAR(iUnites, 64, 3, 1);

	convert_adc_to_GLCD(y_max);
	GLCD_PUTCHAR(iCentaines, 52, 4, 1);
	GLCD_PUTCHAR(iDizaines, 58, 4, 1);
	GLCD_PUTCHAR(iUnites, 64, 4, 1);	

	GLCD_RECT(45, 57, 6, 54);                                     	 // Cadre enregistrer
	GLCD_RECT(45, 57, 71, 121);                                      // Cadre annuler

	GLCD_PUTSTRING("Enregis", 10, 6, 1);							 // Message du bouton
	GLCD_PUTSTRING("Annuler", 77, 6, 1);							 // Message du bouton

	DelayMs(2000); 
	DelayMs(2000); 

	do
	{
		// On teste si l'utilisateur n'a pas appuy sur la croix en haut  droite pour sortir
	    if (detect_touch()==1)														// on n'analyse l'appui que si dtect
        {
			// On lit les valeurs x et y
			x_coord = GetX_panel();
			y_coord = GetY_panel();

			// Si on a appuy sur la croix on revient au menu principal
			if ((x_coord > 110) && (y_coord < 15))
			{
				GLCD_PUTSTRING("X", 122, 0, 1);				// on inverse la couleur
				DelayMs(100);
				iApplication = 0;
				gotoMenuInitial();							// on raffiche le menu de dpart
				return;
			}

			// Si on a appuy sur Enregister
			if ((x_coord>5 && x_coord<50 ) && (y_coord > 45))
			{
				GLCD_PUTSTRING("Enregis", 10, 6, 0);		// on inverse la couleur

				// On enregistre les paramtres
				X_TP_MIN_CALIB = x_min;
				Y_TP_MIN_CALIB = y_min;
				X_TP_MAX_CALIB = x_max;
				Y_TP_MAX_CALIB = y_max;			

				DelayMs(100);
				iApplication = 0;
				gotoMenuInitial();							// on raffiche le menu de dpart
				return;
			}

			// Si on a appuy sur annuler
			if ((x_coord>70 && x_coord<110 ) && (y_coord > 45))
			{
				GLCD_PUTSTRING("Annuler", 77, 6, 0);		// on inverse la couleur
				DelayMs(100);
				iApplication = 0;
				gotoMenuInitial();							// on raffiche le menu de dpart
				return;
			}	
					
		}
     }while (1);
	
}