/* //////////////////////////////////////////////////////////////////////////////////////
Programme pour l'ensemble anmomtre, girouette pour MACC
Auteur: Julien PIASECKI
Mail : pikachu_42@hotmail.com ou julien.piasecki@hotmail.fr
Ensemble de fonctions principales au programme main

///////////////////////////////////////////////////////////////////////////////////////*/
#include <htc.h>
#include "variables_globales.h"
#include "fonctions_globales.h"
#include "glcd.h"
#include "delay.h"
#include "io_config.h"
#include "adc_lib.h"


void init_system(void)
{
	ANSELB = 0;                        // Configure PORTB pins as digital I/O
	ANSELC = 0; 
	ANSELD = 0;                        // Configure PORTD pins as digital I/O
	ANSELE = 0;
	ANSELA = 0xFF;						// port A en
	TRISA = 0xFF;						// tout le port A en entre
	TRISB = 0x00;
	TRISC = 0xFC;						// port C en sortie
	TRISD = 0x00;
	TRISE = 0x00;
	PORTB = 0x00;
	PORTD = 0x00;
	PORTE = 0x00;
	
	GLCD_ON(); 
	GLCD_CLR(); 

    ADCON0 =    0b00000000;
            //0             Unimplemented
            //-00000--      Analog Channel Select bit,00000=AN0
            //------0-      A/D conversion status bit. 1=in progress
            //-------0      ADC enable bit. 0=ADC disabled. 1=ADC enable

    ADCON1 =    0b00000000;
            //0-------      Trigger select bit, 0=CCP5, 1=CTMU
            //-000----      Unimplemented
            //----00--      A/D VRef+ connected to internal signal
            //------00      A/D Vref- connected to internal signal

    ADCON2 =    0b10000111;
            //1-------      0=left justify, 1=right justify
            //-0------      Unpmplemented
            //--000---      ADC clock source selected to Frc
            //-----111      Clock from internal oscillator

/* Configuration du timer 0 	
	T0CS = 0;		// Clock source pour le timer = Internal instruction cycle clock
	T08BIT = 1;		// Timer sur 8 bits, on va compter jusqu' 255 et aprs on recommence
	PSA = 0;		// Prescaler pour TMR0
	PS2	= 0;		// Prescaler de 1 pour TMR0
	PS1 = 0;		// Prescaler de 1 pour TMR0
	PS0 = 0;		// Prescaler de 1 pour TMR0
	TMR0IE = 0;		// Initialisation du timer  0	*/
	TMR0 = 0;		// priode de 1 us
	T0CON = 0xC1;	// Registre de configuration gnral

//
//// Une seconde fera 8000000/(4*4*255) = 1960 cycles d'interruptions sur TMR0 comptant jusqu' 255
//// On considrera que 1960 cycles feront environ 1 seconde de temps rellement mesur
//
///* Interruptions sur le port B[0] pour le signal de l'anmomtre*/
    // bit 7 - GIE/GIEH: Global Interrupt Enable bit
    // bit 6 - PEIE/GIEL: Peripheral Interrupt Enable bit
    // bit 5 - TMR0IE: TMR0 Overflow Interrupt Enable bit
    // bit 4 - INT0IE: INT0 External Interrupt Enable bit
    // bit 3 - RBIE: RB Port Change Interrupt Enable bit
    // bit 2 - TMR0 Overflow Interrupt Flag bit
    // bit 1 - INT0 External Interrupt Flag bit
    // bit 0 - Port B Interrupt-On-Change (IOCx) Interrupt Flag bit
	INTCON = 0xA0;	// Mot de configuration global

	iApplication = 0;		// on passe dans le menu par dfaut
}

void gotoMenuInitial(){
    // On efface l'cran
    GLCD_CLR(); 
		
    // Menu initial
    GLCD_RECT(0, 63, 0, 127);                                    // Cadre extrieur
	GLCD_PUTSTRING("1 - Oscilloscope", 4, 1, 1);
	GLCD_PUTSTRING("2 - Calibration", 4, 2, 1);
	GLCD_PUTSTRING("3 - Test servomoteur", 4, 3, 1);

}

void convert_adc_to_GLCD(int adc_rd)
{
	iMilliers = adc_rd / 1000 ;
	adc_rd = adc_rd - iMilliers*1000;
	iCentaines = adc_rd / 100;
	adc_rd = adc_rd - iCentaines*100;
	iDizaines = adc_rd / 10 ;
	adc_rd = adc_rd - iDizaines*10;
	iUnites = adc_rd;

	// Mise en forme pour afficher le bon caractre ASCII
	iMilliers += 48;
	iCentaines += 48; 
	iDizaines += 48;
	iUnites += 48;

}

///////////////////////////////////////////////////////////////////////////////////////////////////
/* Vecteurs d'interruptions */

void interrupt Interrupt_Isr(void)
{

	// on va modifier le timer pour le pwm dans le mode test servomoteur
	if (iApplication == 3)
	{
		// la sortie PWM tait active, on passe  l'tat bas
		if (PWM_ON==1)
		{
			TMR0IF = 0;			// on efface le flag
			PWM_ON = 0;			// on passe  l'tat bas
			PWM_OUT = 0;		// sortie PWM  0
			TMR0 = 0;			// tat bas pendant 4ms
		} else {

			TMR0IF = 0;					// on efface le flag
			PWM_ON = 1;					// on passe  l'tat haut
			PWM_OUT = 1;				// sortie PWM  1
			TMR0 = (int) fPWM_value;	// tat haut
		}
	}else {

	// Teste si une milliseconde s'est coule pour n'importe quel compteur
		if (TMR0IF==1)  	// Tous les cycles sont faits, 1ms vient de s'couler
		{
			TMR0IF = 0;												// On efface le flag des interruptions des millisecondes pour la prochaine interruption		
			TMR0 = 0;												// on rinitialise le timer	
			compteur_1_us++;										// Toujours incrment, compteur des microsecondes gnrales de tout le programme
			compteur_oscillo_1_us++;								// incrmentation du compteur us oscillo
		}
		if (compteur_oscillo_1_ms == 5)
			iMaj_oscillo_to_do = 1;

		// on a compt 1ms
		if (compteur_1_us == 250)
		{
			compteur_1_us = 0;
			compteur_1_ms++;
		}

		if (compteur_oscillo_1_us == 250)
		{
			compteur_oscillo_1_us = 0;
			compteur_oscillo_1_ms++;
		}
	
		// Test si on a pass une seconde 
		if (compteur_1_ms == Une_sec_OK)
		{
			compteur_s++;
			compteur_1_ms = 0;
		}
	}


} 

void delay_ms(int iNb_ms)
{
	TMR0IF = 0;												// On efface le flag des interruptions des millisecondes pour la prochaine interruption		
	TMR0 = 0;												// on rinitialise le timer	
	compteur_1_ms = 0;

	// on attend le bon nombre de priodes de timer
	do
	{
		asm("nop");
	}while (compteur_1_ms < iNb_ms);
}