/////////////////////////////////////////////////////////////////////////////////////////////
// Pikasoft suite
//
// Auteur: Julien Piasecki
// Mail: pikachu_42@hotmail.com
// Date: 20/02/2015
// Version 1.0
// Plateforme hardware: EasyPic v7
// IDE: mikroC Pro
//
// Fonctionnalits:
// 1 - Oscilloscope avec chelle temporelle variable
//   - Lecture de l'amplitude maximale et enregistrement de Vmax
//   - Utilise par dfaut le potentiomtre de l'ADC pour simuler un signal
//   - Ecran tactile activ pour revenir au menu principal et changer la vue de l'oscillospe
//
// 2 - A venir
/////////////////////////////////////////////////////////////////////////////////////////////

#include <htc.h>
#include "variables_globales.h"
#include "fonctions_globales.h"
#include "glcd.h"
#include "delay.h"
#include "io_config.h"
#include "adc_lib.h"
#include "calibration.h"
#include "oscilloscope.h"
#include "servomoteur.h"



void main() {

	int iDetect = 0;										// Indique si il y a une dtection

	init_system();

	// On initialise le message de dpart sur le Glcd
	GLCD_RECT(0, 63, 0, 127);
	GLCD_PUTSTRING("Pikasoft suite", 4, 0, 1);
	GLCD_PUTSTRING("Aut: Julien Piasecki", 4, 1, 1);
	GLCD_PUTSTRING("pikachu_42@hotmail.com", 4, 2, 1);
	GLCD_PUTSTRING("Date: 20/02/2015", 4, 3, 1);
	GLCD_PUTSTRING("Version 1.0", 4, 4, 1);
	GLCD_PUTSTRING("Hardware: EasyPic v7", 4, 5, 1);
	GLCD_PUTSTRING("IDE: MPLAB v8.92", 4, 6, 1);
	//TP_Set_Calibration_Consts(60, 912, 132, 871);           // Set calibration constants
	DelayMs(5000); 
	GLCD_CLR(); 

    // Menu initial
    gotoMenuInitial();

	iCentaines = 0;
	iDizaines = 0;	
	iUnites = 0;


//boucle infinie
        do
        {
			switch (iApplication)
			{
				case 0: 																			 // on est dans le menu principal
					{					
						 if (detect_touch()==1)													 // on n'analyse l'appui que si dtect
						{
							// On lit les valeurs x et y
							x_coord = GetX_panel();
							y_coord = GetY_panel();

							// Teste l'appui sur oscillospe
							if (y_coord < 12)
							{       
								iApplication = 1;                                            // On passe en mode oscillospe
								GLCD_PUTSTRING("1 - Oscilloscope", 4, 1, 0);                // on inverse la couleur
								DelayMs(100);
								GLCD_PUTSTRING("1 - Oscilloscope", 4, 1, 1);
								break;
							}
								// Teste l'appui sur Calibration
							if ((y_coord < 32) && (y_coord > 20))
							{
								GLCD_PUTSTRING("2 - Calibration", 4, 2, 0);                // on inverse la couleur
								DelayMs(100);
								GLCD_PUTSTRING("2 - Calibration", 4, 2, 1);                // on inverse la couleur
								iApplication = 2;                                          // On passe en mode oscillospe
								break;
							}

								// Teste l'appui sur Test servomoteur
							if ((y_coord < 42) && (y_coord > 30))
							{
								GLCD_PUTSTRING("3 - Test servomoteur", 4, 3, 0);           // on inverse la couleur
								DelayMs(100);
								GLCD_PUTSTRING("3 - Test servomoteur", 4, 3, 1);           // on inverse la couleur
								iApplication = 3;                                          // On passe en mode test servo
								break;
							}
						}
					}
					break;
						
						
				case 1: 																	// on est dans le menu oscilloscope
					{                                       										
							// On efface l'cran
							GLCD_CLR(); 
							GLCD_RECT(0, 63, 0, 127);                                     	 // Cadre extrieur
							GLCD_PUTSTRING("X", 122, 0, 0);								 	 // croix en haut  gauche

							// On appelle la fonction lecture oscilloscope;
							oscilloscope ();
						break;
					}

				case 2: 																	// on est dans le menu oscilloscope
					{                                       										
							// On efface l'cran
							GLCD_CLR(); 

							// On appelle la fonction de calibration;
							calibration ();
						break;
					}


				case 3: 																	// on est dans le test servomoteur
					{                                      										
							// On efface l'cran
							GLCD_CLR(); 
							GLCD_RECT(0, 63, 0, 127);                                     	 // Cadre extrieur
							GLCD_PUTSTRING("X", 122, 0, 0);								 	 // croix en haut  gauche

							// On affiche une ligne de - pour graduer la position
							GLCD_PUTSTRING("-90     0      90", 10, 2, 1);
							GLCD_PUTSTRING("-----------------", 10, 4, 1);

							// On configure le timer
							//TMR0on = 1	// Timer 0 on	
							//T08BIT = 1;	// Timer sur 8 bits, on va compter jusqu' 255 et aprs on recommence
							//T0CS = 0;		// Clock source pour le timer = Internal instruction cycle clock
							//PSA = 0;		// Prescaler pour TMR0
							//PS2	= 1;	// Prescaler de 32 pour TMR0
							//PS1 = 0;		// Prescaler de 32 pour TMR0
							//PS0 = 0;		// Prescaler de 32 pour TMR0
							//TMR0IE = 0;	// Initialisation du timer  0	*/
							T0CON = 0xC4;	// Registre de configuration gnral
							TMR0 = 193;		// valeur pour 1ms

							// On appelle la fonction de test servomoteur
							test_servomoteur();
						break;
					}
   			}     

		// Debug
		convert_adc_to_GLCD(x_coord);
		GLCD_PUTCHAR(iCentaines, 4, 6, 1);
		GLCD_PUTCHAR(iDizaines, 10, 6, 1);
		GLCD_PUTCHAR(iUnites, 16, 6, 1);

		convert_adc_to_GLCD(y_coord);
		GLCD_PUTCHAR(iCentaines, 30, 6, 1);
		GLCD_PUTCHAR(iDizaines, 36, 6, 1);
		GLCD_PUTCHAR(iUnites, 42, 6, 1);

		GLCD_PUTCHAR(	iApplication + 48, 60, 6, 1);

        }while (1);
}
